
:autogenerated:

krotov.objectives module
========================

.. currentmodule:: krotov.objectives

.. automodule:: krotov.objectives
    :members: CtrlCounter, FIX_QUTIP_932, Objective, ensemble_objectives, gate_objectives, summarize_qobj
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

    Summary
    -------

    Classes:

    .. autosummary::
        :nosignatures:

        Objective

    Functions:

    .. autosummary::
        :nosignatures:

        CtrlCounter
        ensemble_objectives
        gate_objectives
        summarize_qobj





    ``__all__``: :func:`CtrlCounter <krotov.objectives.CtrlCounter>`, :class:`Objective <krotov.objectives.Objective>`, :func:`ensemble_objectives <krotov.objectives.ensemble_objectives>`, :func:`gate_objectives <krotov.objectives.gate_objectives>`, :func:`summarize_qobj <krotov.objectives.summarize_qobj>`



    Reference
    ---------